@@ -10,7 +10,7 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 sub _MINIMUM_ETA_TIME { return 10; }
 
@@ -171,7 +171,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =head1 SYNOPSIS
 
@@ -261,11 +261,11 @@ This call will return one L<StatusCodes|WebService::SSLLabs::StatusCodes> instan
 
 =head2 max_assessments
 
-This call will return the maximum number of concurrent assessments the client is allowed to initiate.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<analyze|WebService::SSLLabs/"get_endpoint_data">, L<analyze|WebService::SSLLabs/"info"> or L<analyze|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Max-Assessments header from a successful API call.
+This call will return the maximum number of concurrent assessments the client is allowed to initiate.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<get_endpoint_data|WebService::SSLLabs/"get_endpoint_data">, L<info|WebService::SSLLabs/"info"> or L<get_status_codes|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Max-Assessments header from a successful API call.
 
 =head2 current_assessments
 
-This call will return the number of ongoing assessments submitted by this client.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<analyze|WebService::SSLLabs/"get_endpoint_data">, L<analyze|WebService::SSLLabs/"info"> or L<analyze|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Current-Assessments header in a successful API call.
+This call will return the number of ongoing assessments submitted by this client.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<get_endpoint_data|WebService::SSLLabs/"get_endpoint_data">, L<info|WebService::SSLLabs/"info"> or L<get_status_codes|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Current-Assessments header in a successful API call.
 
 =head1 DIAGNOSTICS
 
